@@ -16,6 +16,7 @@ limitations under the License.
 """
 
 import json
+import urllib.parse
 from .serviceconnector import _Client, ServiceConnector
 from .camel import CamelResource
 from .utils import get_logger
@@ -75,9 +76,10 @@ class Connection(CamelResource):
         :param project: The project from which connection has to be retrieved.
         :return: A Connection object.
         """
-        uri = 'projects/{projectId}/connections/{name}'.format(projectId=project, name=name)
+        conn_svc_url = f'{client._serviceconnector.url.replace("cortex-internal", "cortex-connections")}:4500'
+        uri = f'{conn_svc_url}/internal/projects/{project}/connections/{urllib.parse.quote(name, safe="")}'
         log.debug('Getting connection using URI: %s' % uri)
-        r = client._serviceconnector.request('GET', uri)
+        r = client._serviceconnector.request('GET', uri, is_internal_url=True)
         raise_for_status_with_detail(r)
 
         return r.json()
